// Generated by gmmproc 2.88.0 -- DO NOT MODIFY!


#include <glibmm.h>

#include <giomm/bytesicon.h>
#include <giomm/private/bytesicon_p.h>


/* Copyright (C) 2022 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <gio/gio.h>

namespace
{
} // anonymous namespace


namespace Glib
{

Glib::RefPtr<Gio::BytesIcon> wrap(GBytesIcon* object, bool take_copy)
{
  return Glib::make_refptr_for_instance<Gio::BytesIcon>( dynamic_cast<Gio::BytesIcon*> (Glib::wrap_auto ((GObject*)(object), take_copy)) );
  //We use dynamic_cast<> in case of multiple inheritance.
}

} /* namespace Glib */


namespace Gio
{


/* The *_Class implementation: */

const Glib::Class& BytesIcon_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Class has to know the class init function to clone custom types.
    class_init_func_ = &BytesIcon_Class::class_init_function;

    // This is actually just optimized away, apparently with no harm.
    // Make sure that the parent type has been created.
    //CppClassParent::CppObjectType::get_type();

    // Create the wrapper type, with the same class/instance size as the base type.
    register_derived_type(g_bytes_icon_get_type());

    // Add derived versions of interfaces, if the C type implements any interfaces:
  Icon::add_interface(get_type());
  LoadableIcon::add_interface(get_type());

  }

  return *this;
}


void BytesIcon_Class::class_init_function(void* g_class, void* class_data)
{
  const auto klass = static_cast<BaseClassType*>(g_class);
  CppClassParent::class_init_function(klass, class_data);


}


Glib::ObjectBase* BytesIcon_Class::wrap_new(GObject* object)
{
  return new BytesIcon((GBytesIcon*)object);
}


/* The implementation: */

GBytesIcon* BytesIcon::gobj_copy()
{
  reference();
  return gobj();
}

BytesIcon::BytesIcon(const Glib::ConstructParams& construct_params)
:
  Glib::Object(construct_params)
{

}

BytesIcon::BytesIcon(GBytesIcon* castitem)
:
  Glib::Object((GObject*)(castitem))
{}


BytesIcon::BytesIcon(BytesIcon&& src) noexcept
: Glib::Object(std::move(src))
  , Icon(std::move(src))
  , LoadableIcon(std::move(src))
{}

BytesIcon& BytesIcon::operator=(BytesIcon&& src) noexcept
{
  Glib::Object::operator=(std::move(src));
  Icon::operator=(std::move(src));
  LoadableIcon::operator=(std::move(src));
  return *this;
}


BytesIcon::~BytesIcon() noexcept
{}


BytesIcon::CppClassType BytesIcon::bytesicon_class_; // initialize static member

GType BytesIcon::get_type()
{
  return bytesicon_class_.init().get_type();
}


GType BytesIcon::get_base_type()
{
  return g_bytes_icon_get_type();
}


BytesIcon::BytesIcon(const Glib::RefPtr<const Glib::Bytes>& bytes)
:
  // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Glib::Object(Glib::ConstructParams(bytesicon_class_.init(), "bytes", const_cast<GBytes*>(Glib::unwrap<Glib::Bytes>(bytes)), nullptr))
{
  

}

Glib::RefPtr<BytesIcon> BytesIcon::create(const Glib::RefPtr<const Glib::Bytes>& bytes)
{
  return Glib::make_refptr_for_instance<BytesIcon>( new BytesIcon(bytes) );
}

Glib::RefPtr<const Glib::Bytes> BytesIcon::get_bytes() const
{
  auto retvalue = Glib::wrap(g_bytes_icon_get_bytes(const_cast<GBytesIcon*>(gobj())));
  if(retvalue)
    retvalue->reference(); //The function does not do a ref for us.
  return retvalue;
}


static_assert(Glib::Traits::ValueCompatibleWithWrapProperty<Glib::RefPtr<Glib::Bytes>>::value,
  "Type Glib::RefPtr<Glib::Bytes> cannot be used in _WRAP_PROPERTY. "
  "There is no suitable template specialization of Glib::Value<>.");

Glib::PropertyProxy_ReadOnly< Glib::RefPtr<Glib::Bytes> > BytesIcon::property_bytes() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::RefPtr<Glib::Bytes> >(this, "bytes");
}


} // namespace Gio


